@@ -59,7 +59,7 @@ where
                                 .map(|var| var.is_fn_local)
                                 .unwrap_or(false)
                             {
-                                log::debug!(
+                                tracing::debug!(
                                     "dead_code: Dropping an assigment to a varaible declared in \
                                      function because function is being terminated"
                                 );
