@@ -43,7 +43,7 @@ where
         }
 
         self.changed = true;
-        log::debug!("loops: Removing a for loop with instant break");
+        tracing::debug!("loops: Removing a for loop with instant break");
         self.prepend_stmts
             .extend(f.init.take().map(|init| match init {
                 VarDeclOrExpr::VarDecl(var) => Stmt::Decl(Decl::Var(var)),
@@ -76,7 +76,7 @@ where
                         let changed = UnreachableHandler::preserve_vars(stmt);
                         self.changed |= changed;
                         if changed {
-                            log::debug!(
+                            tracing::debug!(
                                 "loops: Removing unreachable while statement without side effects"
                             );
                         }
@@ -84,7 +84,9 @@ where
                         let changed = UnreachableHandler::preserve_vars(&mut w.body);
                         self.changed |= changed;
                         if changed {
-                            log::debug!("loops: Removing unreachable body of a while statement");
+                            tracing::debug!(
+                                "loops: Removing unreachable body of a while statement"
+                            );
                         }
                     }
                 }
@@ -96,7 +98,7 @@ where
                         let changed = UnreachableHandler::preserve_vars(&mut f.body);
                         self.changed |= changed;
                         if changed {
-                            log::debug!("loops: Removing unreachable body of a for statement");
+                            tracing::debug!("loops: Removing unreachable body of a for statement");
                         }
                         self.changed |= f.init.is_some() | f.update.is_some();
 
@@ -118,7 +120,7 @@ where
                     } else if let Known(true) = val {
                         if purity.is_pure() {
                             self.changed = true;
-                            log::debug!(
+                            tracing::debug!(
                                 "loops: Remving `test` part of a for stmt as it's always true"
                             );
                             f.test = None;
@@ -154,7 +156,7 @@ where
                     } else {
                         s.init = None;
                         self.changed = true;
-                        log::debug!(
+                        tracing::debug!(
                             "loops: Removed side-effect-free expressions in `init` of a for stmt"
                         );
                     }
